macro_rules! exception {
( $rust_err:ty, $module:expr, $py_err:ident, $base:ty $(, $doc:expr)? $(,)? ) => { ... };
}Expand description
Create a Python exception and a conversion from its Rust type. Note that the exception class must still be added to the module.